@@ -24,10 +24,10 @@ import sys
 
 from pbr.version import VersionInfo
 
-if sys.version_info < (3,) or sys.version_info < (3, 5):
+if sys.version_info < (3,) or sys.version_info < (3, 6):
     raise ImportError("""You are trying to run faucet on python {py}
 
-Faucet is not compatible with python {py}, please upgrade to python 3.5 or newer."""
+Faucet is not compatible with python {py}, please upgrade to python 3.6 or newer."""
                       .format(py='.'.join([str(v) for v in sys.version_info[:3]])))
 
 RYU_OPTIONAL_ARGS = [
@@ -57,8 +57,6 @@ RYU_OPTIONAL_ARGS = [
     ('ofp-tcp-listen-port', 'openflow tcp listen port (default: 6653)'),
     ('pid-file', 'pid file name'),
     ('user-flags', 'Additional flags file for user applications'),
-    ('wsapi-host', 'webapp listen host (default 0.0.0.0)'),
-    ('wsapi-port', 'webapp listen port (default 8080)')
 ]
 
 
@@ -81,7 +79,7 @@ def parse_args(sys_args):
     args.add_argument(
         '--use-syslog', action='store_true', help='output to syslog')
     args.add_argument(
-        '--ryu-app',
+        '--ryu-app-lists',
         action='append',
         help='add Ryu app (can be specified multiple times)',
         metavar='APP')
@@ -89,12 +87,12 @@ def parse_args(sys_args):
     for ryu_arg in RYU_OPTIONAL_ARGS:
         if len(ryu_arg) >= 3:
             args.add_argument(
-                '--ryu-%s' % ryu_arg[0],
+                f'--ryu-{ryu_arg[0]}',
                 help=ryu_arg[1],
                 default=ryu_arg[2])
         else:
             args.add_argument(
-                '--ryu-%s' % ryu_arg[0],
+                f'--ryu-{ryu_arg[0]}',
                 help=ryu_arg[1])
 
     return args.parse_args(sys_args)
@@ -131,12 +129,12 @@ def build_ryu_args(argv):
     for arg, val in vars(args).items():
         if not val or not arg.startswith('ryu'):
             continue
-        if arg == 'ryu_app':
+        if arg == 'ryu_app_lists':
             continue
         if arg == 'ryu_config_file' and not os.path.isfile(val):
             continue
         arg_name = arg.replace('ryu_', '').replace('_', '-')
-        ryu_args.append('--%s=%s' % (arg_name, val))
+        ryu_args.append(f'--{arg_name}={val}')
 
     # Running Faucet or Gauge?
     if args.gauge or os.path.basename(prog) == 'gauge':
@@ -145,11 +143,11 @@ def build_ryu_args(argv):
         ryu_args.append('faucet.faucet')
 
     # Check for additional Ryu apps.
-    if args.ryu_app:
-        ryu_args.extend(args.ryu_app)
+    if args.ryu_app_lists:
+        ryu_args.extend(args.ryu_app_lists)
 
     # Replace current process with ryu-manager from PATH (no PID change).
-    ryu_args.insert(0, 'ryu-manager')
+    ryu_args.insert(0, 'osken-manager')
     return ryu_args
 
 
